==> jmp_0.42.orig.tar.gz: jmp-0.42.orig/jmp_JMPController.c <==
#include <jni.h>
#include <jmp.h>
#include <jmp_JMPController.h>

JNIEXPORT jint JNICALL Java_jmp_JMPController_runDataDump (JNIEnv *e, jclass c) {
    int f = run_data_dump ();
    return (jint)f;
}

JNIEXPORT void JNICALL Java_jmp_JMPController_runHeapDump (JNIEnv *e , jclass c) {
    run_heap_dump ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_runGC (JNIEnv *e, jclass c) {
    run_GC ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_enableObjectEvents (JNIEnv *e, jclass c) {
    enable_object_events ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_disableObjectEvents (JNIEnv *e, jclass c) {
    disable_object_events ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_enableMethodEvents (JNIEnv *e, jclass c) {
    enable_method_events ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_disableMethodEvents (JNIEnv *e, jclass c) {
    disable_method_events ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_enableMonitorEvents (JNIEnv *e, jclass c) {
    enable_monitor_events ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_disableMonitorEvents (JNIEnv *e, jclass c) {
    disable_monitor_events ();
}

/* Emacs Local Variables: */
/* Emacs mode:C */
/* Emacs c-indentation-style:"gnu" */
/* Emacs c-hanging-braces-alist:((brace-list-open)(brace-entry-open)(defun-open after)(substatement-open after)(block-close . c-snug-do-while)(extern-lang-open after)) */
/* Emacs c-cleanup-list:(brace-else-brace brace-elseif-brace space-before-funcall) */
/* Emacs c-basic-offset:4 */
/* Emacs End: */

==> jmp_0.48.orig.tar.gz: jmp-0.48/jmp_JMPController.c <==
#include <jni.h>
#include <jmp.h>
#include <jmp_JMPController.h>

JNIEXPORT jint JNICALL Java_jmp_JMPController_runDataDump (JNIEnv *e, jclass c) {
    int f = run_data_dump ();
    return (jint)f;
}

JNIEXPORT void JNICALL Java_jmp_JMPController_runHeapDump (JNIEnv *e , jclass c) {
    run_heap_dump ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_runStringDump (JNIEnv *e, jclass c) {
    run_string_dump ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_runGC (JNIEnv *e, jclass c) {
    run_GC ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_enableObjectEvents (JNIEnv *e, jclass c) {
    enable_object_events ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_disableObjectEvents (JNIEnv *e, jclass c) {
    disable_object_events ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_enableMethodEvents (JNIEnv *e, jclass c) {
    enable_method_events ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_disableMethodEvents (JNIEnv *e, jclass c) {
    disable_method_events ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_enableMonitorEvents (JNIEnv *e, jclass c) {
    enable_monitor_events ();
}

JNIEXPORT void JNICALL Java_jmp_JMPController_disableMonitorEvents (JNIEnv *e, jclass c) {
    disable_monitor_events ();
}

/* Emacs Local Variables: */
/* Emacs mode:C */
/* Emacs c-indentation-style:"gnu" */
/* Emacs c-hanging-braces-alist:((brace-list-open)(brace-entry-open)(defun-open after)(substatement-open after)(block-close . c-snug-do-while)(extern-lang-open after)) */
/* Emacs c-cleanup-list:(brace-else-brace brace-elseif-brace space-before-funcall) */
/* Emacs c-basic-offset:4 */
/* Emacs End: */
